2026.03.16 v0.9.0
- migrate branch name from master to main
- drop 2.x support, add 3.10+ support
- migrate travis to github aciton
- migrate to uv

2020.06.02 v0.8.0
- support relative path for download path
- add install script
- fuzzy find support(with grep or fzf)
- drop 3.3/3.4 support, add 3.6+ support

2017.06.26 v0.7.0
- support the new syntax, #22

2017.05.07 v0.6.0
- support search commands in other platforms, #20

2016.01.14 v0.5.0
- support locate the command page, #11

2016.01.12 v0.4.0
- support custom the configuration file via `TLDR_CONFIG_DIR`, #9

2016.01.05 v0.3.0
- support rebuild the index(#8), and rebuild the index after updating
- improve tests, #12

2015.10.21 v0.2.0
- python3.x support
- add tests and code coverage
- return parsed lines instead of print them directly
- improve error output when detect unsupported color

2015.09.22 v0.1.1
- fix the update command

2015.09.10 v0.1.0
- first public release
